<?php
/**
 * Batch processing
 * 
 * @package
 */
namespace WPFunnels\Batch\Elementor;

use WPFunnels\Batch\Divi\Wpfnl_Divi_Source;
use WPFunnels\Batch\Gutenberg\Wpfnl_Gutenberg_Batch;
use WPFunnels\Batch\Gutenberg\Wpfnl_Gutenberg_Source;
use WPFunnels\Batch\Wpfnl_Divi_Batch;
use WPFunnels\Batch\Wpfnl_Elementor_Batch;
use WPFunnels\Traits\SingletonTrait;
use WPFunnels\Wpfnl_functions;
class Wpfnl_Batch
{
	use SingletonTrait;

	/**
	 * Elementor batch instance
	 *
	 * @var Wpfnl_Elementor_Batch
	 */
    protected $elementor_batch;

	/**
	 * Elementor source object
	 *
	 * @var Wpfnl_Elementor_Source
	 */
    protected $elementor_source;

	/**
	 * Gutenberg batch instance
	 *
	 * @var Wpfnl_Gutenberg_Batch
	 */
    protected $gutenberg_batch;

	/**
	 * Gutenberg source object
	 *
	 * @var Wpfnl_Gutenberg_Source
	 */
    protected $gutenberg_source;

	/**
	 * Divi batch instance
	 *
	 * @var Wpfnl_Divi_Batch
	 */
	protected $divi_batch;

	/**
	 * Divi source object
	 *
	 * @var Wpfnl_Divi_Source
	 */
	protected $divi_source;


	/**
	 * Oxygen source object
	 * 
	 * @var Oxygen source
	 */
	protected $oxygen_source;

    public function __construct()
    {
        $page_builder = Wpfnl_functions::get_builder_type();

        if ( 'elementor' === $page_builder ) {
            $this->elementor_batch 	= new Wpfnl_Elementor_Batch();
        }

        if ( 'gutenberg' === $page_builder ) {
            $this->gutenberg_batch 	= new Wpfnl_Gutenberg_Batch();
        }

		if ( 'divi-builder' === $page_builder ) {
			$this->divi_batch 	= new Wpfnl_Divi_Batch();
		}

		add_action( 'wpfunnels_after_step_import', [$this, 'start_processing'], 10, 2 );
    }

    /**
     * Start the batch import process
     *
     * @param int $step_id
     * @param string $builder
	 * 
     * @since 1.0.0
     */
    public function start_processing($step_id = 0, $builder = 'elementor')
    {
		if( $step_id && !Wpfnl_functions::maybe_duplicate_step( $step_id ) ){
			if ( 'elementor' === $builder && class_exists('\Elementor\Plugin') ) {
				$this->elementor_batch->push_to_queue($step_id);
				$this->elementor_batch->save()->dispatch();
			}
	
			if ( 'gutenberg' === $builder ) {
				$this->gutenberg_batch->push_to_queue($step_id);
				$this->gutenberg_batch->save()->dispatch();
			}
	
			if ( 'divi-builder' === $builder ) {
				$this->divi_batch->push_to_queue($step_id);
				$this->divi_batch->save()->dispatch();
			}
		}
    }
}
